# Bugsink: Self-hosted Error Tracking 

Bugsink offers real-time [error tracking](https://www.bugsink.com/error-tracking/) for your applications with full control
through self-hosting. 

* [Built to self-host](https://www.bugsink.com/built-to-self-host/)
* [Sentry-compatible SDKs](https://www.bugsink.com/connect-any-application/)
* [Scalable and reliable](https://www.bugsink.com/scalable-and-reliable/)

### Screenshot

This is what you'll get:

![Screenshot](https://www.bugsink.com/static/images/JsonSchemaDefinitionException.5e02c1544273.png)


### Installation & docs

[Detailed installation instructions](https://www.bugsink.com/docs/installation/) on the Bugsink website, Pythonists
may try their luck without reading the docs by doing a

```
pip install bugsink
```

[More information and documentation](https://www.bugsink.com/)
